@@ -26,11 +26,11 @@ Lavoco::Web::App - Experimental framework with two constraints: FastCGI and Temp
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 $VERSION = eval $VERSION;
 
@@ -68,6 +68,7 @@ has _socket    => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build__so
 has  templates => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build_templates' );
 has  filename  => ( is => 'rw', isa => 'Str',  lazy => 1, builder => '_build_filename'  );
 has  config    => ( is => 'rw', isa => 'HashRef' );
+has _mtime     => ( is => 'rw', isa => 'Num', default => 0 );
 
 sub _build_base
 {
@@ -558,8 +559,6 @@ sub _handler
 
         $stash{ took } = join( '.', gettimeofday ) - $stash{ started };
         
-        $log->debug( "The stash contains...", \%stash );
-        
         $log->debug( "Took " . sprintf("%.5f", $stash{ took } ) . " seconds");
 
         #######################################
@@ -594,8 +593,8 @@ sub _sitemap
     $sitemap .= "\n";
 
     # need to do proper recursion here
-        
-    foreach my $each_page ( @{ $stash->{ config }->{ pages } } )
+
+    foreach my $each_page ( @{ $stash->{ app }->config->{ pages } } )
     {
         $sitemap .= "<url><loc>" . $base . $each_page->{ path } . "</loc></url>\n";
 
@@ -668,6 +667,10 @@ sub _reload_config
 
     my $log = $args{ log };    
 
+    my $mtime = ( stat $self->filename )[ 9 ];
+
+    return $self if $mtime == $self->_mtime;
+
     $log->debug( "Opening config file: " . $self->filename );
 
     my $string = read_file( $self->filename, { binmode => ':utf8' } );
@@ -684,6 +687,10 @@ sub _reload_config
 
     $log->debug( $@ ) if $@;
 
+    $self->_mtime( ( stat $self->filename )[ 9 ] );
+
+    $log->debug( $self->filename . " last modified " . $self->_mtime );
+
     return $self;
 }
 
